/**
 * ClusterTree - A JTree representing Solaris packages
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.pkgview;

import javax.swing.tree.*;
import java.util.*;

public class ClusterTree {

    /**
     * Create a tree from a clustertoc file and add it to the parent node
     *
     * @param topmenu A tree node to attach the tree to
     * @param ctoc A parsed cluster table of contents
     */
    public ClusterTree(DefaultMutableTreeNode topmenu, ClusterToc ctoc) {
	Map <String, MetaCluster> MetaClusters = ctoc.getMetaClusters();
	// outer loop over metaclusters
	for (String s : MetaClusters.keySet()) {
	    DefaultMutableTreeNode mitem = new DefaultMutableTreeNode(s);
	    topmenu.add(mitem);
	    MetaCluster mc = MetaClusters.get(s);
	    for (PackageCluster pc : mc.getClusters()) {
		mitem.add(addNode(pc));
	    }
	    for (SolarisPackage pkg : mc.getPackages()) {
		mitem.add(new DefaultMutableTreeNode(pkg));
	    }
	}
    }

    /**
     * Create a tree from a clustertoc file and add it to the parent node
     *
     * @param topmenu A tree node to attach the tree to
     * @param ctoc A parsed cluster table of contents
     * @param cluster The top-level metacluster to show
     */
    public ClusterTree(DefaultMutableTreeNode topmenu, ClusterToc ctoc,
		String cluster) {
	MetaCluster mc = ctoc.getMetaCluster(cluster);
	if (mc != null) {
	    for (PackageCluster pc : mc.getClusters()) {
		topmenu.add(addNode(pc));
	    }
	    for (SolarisPackage pkg : mc.getPackages()) {
		topmenu.add(new DefaultMutableTreeNode(pkg));
	    }
	}
    }

    // create the tree for a cluster
    private DefaultMutableTreeNode addNode(PackageCluster pc) {
	DefaultMutableTreeNode mitem = new DefaultMutableTreeNode(pc);
	for (SolarisPackage pkg : pc.getPackages()) {
	    mitem.add(new DefaultMutableTreeNode(pkg));
	}
	return mitem;
    }
}
