/**
 * DistributionSoftwarePanel
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.pkgview;

import javax.swing.*;

/**
 * Generates a view of the software available on a distribution media.
 * It is broken into two tabs, which show a list of available packages,
 * and a tree view based on installation clusters.
 */
public class DistributionSoftwarePanel extends JTabbedPane {

    private boolean showselected;

    private ClusterToc ctoc;
    private PkgList plist;
    private DistributionPackagePanel dpp;
    private DistributionClusterPanel dcp;
    private PackageProfile profile;

    PkgResources pkgres;

    public DistributionSoftwarePanel(String s) {
	this(s, false, (PackageProfile) null);
    }

    public DistributionSoftwarePanel(String s, boolean showselected,
				    PackageProfile profile) {
	this.showselected = showselected;
	this.profile = profile;

	pkgres = PkgResources.getInstance();

	plist = new PkgList(s);
	ctoc = new ClusterToc(s, plist);

	initialize();
    }

    public DistributionSoftwarePanel(ClusterToc ctoc, PkgList plist,
				boolean showselected, PackageProfile profile) {
	this.ctoc = ctoc;
	this.plist = plist;
	this.showselected = showselected;
	this.profile = profile;

	pkgres = PkgResources.getInstance();

	initialize();
    }

    private void initialize() {
	dpp = new DistributionPackagePanel(plist, ctoc, showselected, profile);
	add(pkgres.getString("PKG.LIST"), dpp);

	if (ctoc.exists()) {
	    dcp = new DistributionClusterPanel(plist, ctoc, showselected,
					profile);
	    add(pkgres.getString("PKG.TREE"), dcp);
	}

	createRevDependencies();
    }

    // FIXME do we need both?
    private void createRevDependencies() {
	dpp.createRevDependencies();
	if (ctoc.exists()) {
	    dcp.createRevDependencies();
	}
    }

    public void setMetaCluster(String metacluster) {
	dpp.setMetaCluster(metacluster);
	if (ctoc.exists()) {
	    dcp.setMetaCluster(metacluster);
	}
	profile.initialize(ctoc.getMetaCluster(metacluster));
    }

    public void useInstalledSystem(InstalledCluster iclust) {
	String metacluster = iclust.getClusterName();
	dpp.setMetaCluster(metacluster);
	if (ctoc.exists()) {
	    dcp.setMetaCluster(metacluster);
	}
	profile.initialize(ctoc.getMetaCluster(metacluster));
    }
}
