/**
 * PatchPanel
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.pkgview;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

/**
 * Show a list of patches. There's a list of patches on the left, with
 * information about that patch on the right.
 */
public class PatchPanel extends JPanel {

    private PatchInformationPanel pip;

    public PatchPanel(PkgList pkglist) {
	this(new PatchList(pkglist));
    }

    public PatchPanel(PatchList patchlist) {
	setLayout(new BorderLayout());
	Vector v = new Vector <SolarisPatch> (patchlist.getPatches());
	JList jplistpanel = new JList(v);
	jplistpanel.addMouseListener(mouseListener);
	jplistpanel.addKeyListener(keyListener);
	pip = new PatchInformationPanel();
	JSplitPane psplit = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT,
		new JScrollPane(jplistpanel), pip);
	psplit.setOneTouchExpandable(true);
	psplit.setDividerLocation(120);
	add(psplit);
    }

    MouseListener mouseListener = new MouseAdapter() {
	public void mouseClicked(MouseEvent e) {
	    Cursor c = getCursor();
	    setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
	    JList source = (JList) e.getSource();
	    setPatchInfo((SolarisPatch) source.getSelectedValue());
	    setCursor(c);
	}
    };

    KeyListener keyListener = new KeyAdapter() {
	public void keyReleased(KeyEvent e) {
	    Cursor c = getCursor();
	    setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
	    JList source = (JList) e.getSource();
	    setPatchInfo((SolarisPatch) source.getSelectedValue());
	    setCursor(c);
	}
    };

    public void setPatchInfo(SolarisPatch patch) {
	pip.display(patch);
    }
}
