/**
 * ProfileDisplayPanel - display a jumpstart profile
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.pkgview;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import uk.co.petertribble.jingle.JingleTextPane;

public class ProfileDisplayPanel extends JPanel implements ActionListener {

    private PackageProfile profile;

    private JingleTextPane tp;
    private JButton displayButton;
    private JButton pkglistButton;
    private JButton saveButton;

    private PkgResources pkgres;

    public ProfileDisplayPanel(PackageProfile profile) {
	this.profile = profile;
	pkgres = PkgResources.getInstance();

	setLayout(new BorderLayout());

	tp = new JingleTextPane();
	add(new JScrollPane(tp));

	JPanel buttonPanel = new JPanel();

	displayButton = new JButton(pkgres.getString("JS.MSG.SHOWPROFILE"));
	displayButton.addActionListener(this);
	displayButton.setEnabled(true);
	buttonPanel.add(displayButton);

	pkglistButton = new JButton(pkgres.getString("JS.MSG.SHOWPKGS"));
	pkglistButton.addActionListener(this);
	pkglistButton.setEnabled(true);
	buttonPanel.add(pkglistButton);

	saveButton = new JButton(pkgres.getString("JS.MSG.SAVE"));
	saveButton.addActionListener(this);
	saveButton.setEnabled(true);
	buttonPanel.add(saveButton);

	add(buttonPanel, BorderLayout.SOUTH);

	validate();

    }

    /**
     * Saves the current profile as a text file. The user can select the
     * filename, and is asked to confirm the overwrite of an existing file.
     */
    public void saveProfile() {
	JFileChooser fc = new JFileChooser();
	int dosave = fc.showSaveDialog(this);
	if (dosave == JFileChooser.APPROVE_OPTION) {
	    File f = fc.getSelectedFile();
	    if (f.exists()) {
		int ok = JOptionPane.showConfirmDialog(this,
		    pkgres.getString("SAVEAS.OVERWRITE.TEXT") + " "
								+ f.toString(),
		    pkgres.getString("SAVEAS.CONFIRM.TEXT"),
		    JOptionPane.YES_NO_OPTION);
		if (ok != JOptionPane.YES_OPTION) {
		    return;
		}
	    }
	    try {
		FileWriter fw = new FileWriter(f);
		String s = profile.getProfile();
		fw.write(s, 0, s.length());
		fw.close();
	    } catch (Exception ioe) {
		JOptionPane.showMessageDialog(this, ioe.toString(),
			pkgres.getString("SAVEAS.ERROR.TEXT"),
			JOptionPane.ERROR_MESSAGE);
	    }
	}
    }

    /*
     * Show the current jumpstart profile.
     */
    private void showProfile() {
	tp.setText(profile.getProfile());
    }

    /*
     * Show a simple list of all packages contained in the current profile.
     */
    private void showPkglist() {
	tp.setText(profile.getPkglist());
    }

    public void actionPerformed(ActionEvent e) {
	if (e.getSource() == displayButton) {
	    showProfile();
	}
	if (e.getSource() == saveButton) {
	    saveProfile();
	}
	if (e.getSource() == pkglistButton) {
	    showPkglist();
	}
    }
}
