/**
 * SmfPanel - shows smf status
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview;

import javax.swing.*;
import javax.swing.tree.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;

public class SmfPanel extends JPanel {

    private SmfList plist;
    private SmfTree ptree;
    private SmfInfoPanel sip;

    /**
     * Display an smf information panel
     */
    public SmfPanel() {
	setLayout(new BorderLayout());

	SolViewResources svr = SolViewResources.getInstance();

	plist = new SmfList();
	plist.addMouseListener(mouseListener);

	ptree = new SmfTree(svr.getString("SMF.SERVICES"));
	ptree.addTreeSelectionListener(new TreeSelectionListener() {
	    public void valueChanged(TreeSelectionEvent e) {
		DefaultMutableTreeNode node = (DefaultMutableTreeNode)
		    ptree.getLastSelectedPathComponent();

		if ((node != null) && node.isLeaf()) {
		    setInfo((String) node.getUserObject());
		}
	    }
	});
	// end of tree listener


	JTabbedPane jtp = new JTabbedPane();

	jtp.add(svr.getString("SMF.LIST"), new JScrollPane(plist));
	jtp.add(svr.getString("SMF.TREE"), new JScrollPane(ptree));

	sip = new SmfInfoPanel();

	JSplitPane psplit = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT,
		jtp, sip);
	psplit.setOneTouchExpandable(true);
	psplit.setDividerLocation(180);
	add(psplit);
    }

    private void setInfo(String s) {
	sip.setText(plist.getHtmlInfo(s));
	sip.setLog(plist.getLog(s));
    }

    MouseListener mouseListener = new MouseAdapter() {
	public void mouseClicked(MouseEvent e) {
	    Cursor c = getCursor();
	    setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
	    JList source = (JList) e.getSource();
	    setInfo((String) source.getSelectedValue());
	    setCursor(c);
	}
    };

}
