/**
 * SmfUtils - shows available Solaris services
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview;

import java.util.*;
import java.io.File;
import uk.co.petertribble.solview.helpers.RunCommand;
import uk.co.petertribble.jumble.JumbleFile;

public class SmfUtils {

    private List <String> services;
    private Map <String, SmfService> serviceMap;

    public SmfUtils() {
	serviceMap = new HashMap <String, SmfService> ();
	services = new ArrayList <String> ();
	RunCommand svcs = new RunCommand("/usr/bin/svcs -aH");
	// parse the svcs output to get the service name and status
	StringTokenizer st = new StringTokenizer(svcs.getOut(), "\n");
	while (st.hasMoreTokens()) {
	    String[] ds = st.nextToken().split("\\s+", 3);
	    // must check we got at least 3 back
	    serviceMap.put(ds[2], new SmfService(ds[2], ds[0], ds[1]));
	    services.add(ds[2]);
	}
    }

    public List <String> getServices() {
	return services;
    }

    public String getStatus(String s) {
	return serviceMap.get(s).getStatus();
    }

    public SmfService getService(String s) {
	return serviceMap.get(s);
    }

    public String getHtmlInfo(String s) {
	SmfService smfserv = getService(s);
	String status = smfserv.getStatus();
	if (status.equals("offline") || status.equals("disabled")) {
	    return "<pre>" + smfserv.getExplanation() + "</pre>";
	}
	if (status.equals("online")) {
	    StringBuilder sb = new StringBuilder();
	    sb.append("<p bgcolor=\"#cccccc\">");
	    sb.append("<b>Service and Processes</b></p>");
	    sb.append("<pre>").append(smfserv.getProcesses()).append("</pre>");
	    sb.append("<p bgcolor=\"#cccccc\">");
	    sb.append("<b>Services this service depends on</b></p>");
	    sb.append("<pre>").append(smfserv.getDependencies());
	    sb.append("</pre>");
	    sb.append("<p bgcolor=\"#cccccc\">");
	    sb.append("<b>Services that depend on this service</b></p>");
	    sb.append("<pre>").append(smfserv.getDependents()).append("</pre>");
	    return sb.toString();
	}
	if (status.equals("legacy_run")) {
	    StringBuilder sb = new StringBuilder();
	    // FIXME this is one of the ugliest hacks I've ever seen
	    String script = s.substring(4, 12) + "." + s.substring(13);
	    sb.append("<p bgcolor=\"#cccccc\"><b>");
	    sb.append("This is a legacy script, file name ").append(script);
	    sb.append("</b></p>");
	    File fl = new File(script);
	    if (fl.exists()) {
		sb.append("<pre>\n");
		sb.append("\n\nScript Contents:\n\n");
		sb.append(JumbleFile.getStringContents(fl));
		sb.append("</pre>\n");
	    } else {
		sb.append("\n\n(Script file not found)\n");
	    }
	    return sb.toString();
	}
	return status;
    }

    public String getLog(String s) {
	SmfService smfserv = getService(s);
	String fmri = smfserv.getFMRI();
	/*
	 * We need to break down the fmri, removing the initial svc:
	 * and the leading /, then replacing subsequent / by -. Then
	 * look for that in the /var/svc/log directory.
	 */
	String ds[] = fmri.split("/");
	StringBuilder sb = new StringBuilder();
	for (int i = 1; i < ds.length-1; i++) {
	    sb.append(ds[i]).append("-");
	}
	sb.append(ds[ds.length-1]).append(".log");
	File fl = new File("/var/svc/log", sb.toString());
	if (fl.exists()) {
	    StringBuilder sb2 = new StringBuilder();
	    sb2.append("<pre>\n");
	    sb2.append(JumbleFile.getStringContents(fl));
	    sb2.append("</pre>\n");
	    return sb2.toString();
	}
	return (String) null;
    }

}
