/**
 * SolToolsMenu - standard toolbar menu for solview tools
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview;

import javax.swing.*;
import java.awt.event.*;
import uk.co.petertribble.solview.helpers.RunInXterm;
import java.util.*;
import java.io.File;

public class SolToolsMenu extends JMenu implements ActionListener {

    private Map <String, String> toolMap;

    public SolToolsMenu() {
	super(SolViewResources.getString("TOOLS.TEXT"));
	toolMap = new HashMap <String, String> ();

	addItem("Top", "/usr/local/bin/top", (String) null);
	addItem("Top", "/opt/sfw/bin/top", (String) null);
	addItem("Prstat", "/usr/bin/prstat", (String) null);
	addItem("Mpstat", "/usr/bin/mpstat", "1");
	addItem("Vmstat", "/usr/bin/vmstat", "1");
	addItem("IOstat", "/usr/bin/iostat", "-xnz 1");
    }

    /**
     * Add a command to the tools menu. It is only added if the executable
     * exists, and if this tool hasn't been added already. So this can be
     * called multiple times with different paths, and the first location
     * found will be the one that is used.
     */
    private void addItem(String text, String cmd, String args) {
	File f = new File(cmd);
	if (f.exists() &&
			!toolMap.containsKey(text)) {
	    if (args == null) {
		toolMap.put(text, cmd);
	    } else {
		toolMap.put(text, cmd + " " + args);
	    }
	    JMenuItem ji = new JMenuItem(text);
	    ji.addActionListener(this);
	    add(ji);
	}
    }

    public void actionPerformed(ActionEvent e) {
	JMenuItem jmi = (JMenuItem) e.getSource();
	new RunInXterm(toolMap.get(jmi.getText()));
    }

}
