/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */

package uk.co.petertribble.solview.explorer;

import uk.co.petertribble.jkstat.api.JKstat;
import uk.co.petertribble.jkstat.api.KstatAggregate;
import uk.co.petertribble.jkstat.gui.KstatAccessoryPanel;
import java.awt.*;
import java.awt.geom.Rectangle2D;

public class AggregateCpuPanel extends KstatAccessoryPanel {

    private KstatAggregate ksa;
    private long luser;
    private long lsys;
    private long lwait;
    private long lidle;
    private long nuser;
    private long nsys;
    private long nwait;
    private long nidle;
    private long duser;
    private long dsys;
    private long dwait;
    private long didle;
    private long dtotal;

    /**
     * Create a panel showing the input and output traffic on the
     * given kstat that updates every interval seconds.
     */
    public AggregateCpuPanel(KstatAggregate ksa,
			int interval, JKstat jkstat) {
	super("", 0, "", interval, jkstat);

	this.ksa = ksa;

	setMinimumSize(new Dimension(64, 32));
	setPreferredSize(new Dimension(64, 32));

	updateAccessory();

	// kick a timer into life
	startLoop();
    }

    @Override
    public void updateAccessory() {
	ksa.read();
	nuser = ksa.aggregate("user");
	nsys = ksa.aggregate("kernel");
	nwait = ksa.aggregate("wait");
	nidle = ksa.aggregate("idle");

	duser = nuser - luser;
	dsys = nsys - lsys;
	dwait = nwait - lwait;
	didle = nidle - lidle;

	dtotal = duser + dsys + dwait + didle;

	repaint();

	luser = nuser;
	lsys = nsys;
	lwait = nwait;
	lidle = nidle;
    }

    public void paint(Graphics g) {
	Graphics2D g2 = (Graphics2D) g;
	Dimension d = getSize();
	int w = d.width;
	int h = d.height;
	double dscale = ((double) w)/((double) dtotal);
	long x = 0;
	long dx = didle;
	g2.setPaint(Color.BLUE);
	g2.fill(new Rectangle2D.Double(dscale*((double) x), 0,
		dscale*((double) dx), h));
	x += didle;
	dx = dwait;
	g2.setPaint(Color.RED);
	g2.fill(new Rectangle2D.Double(dscale*((double) x), 0,
		dscale*((double) dx), h));
	x += dwait;
	dx = duser;
	g2.setPaint(Color.GREEN);
	g2.fill(new Rectangle2D.Double(dscale*((double) x), 0,
		dscale*((double) dx), h));
	x += duser;
	dx = dsys;
	g2.setPaint(Color.YELLOW);
	g2.fill(new Rectangle2D.Double(dscale*((double) x), 0,
		dscale*((double) dx), h));
    }

}
