/**
 * CpuInfoPanel - shows Cpu status
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview.explorer;

import javax.swing.*;
import uk.co.petertribble.jkstat.api.Kstat;
import uk.co.petertribble.jkstat.api.JKstat;
import uk.co.petertribble.jkstat.gui.AccessoryCpuPanel;
import uk.co.petertribble.jingle.JingleTextPane;

public class CpuInfoPanel extends InfoPanel {

    private JingleTextPane tp;
    private ProcessorTree proctree;
    private AccessoryCpuPanel acp;
    private JKstat jkstat;

    /**
     * Display a Cpu information panel.
     */
    public CpuInfoPanel(SysItem hi, JKstat jkstat) {
	super(hi);
	this.jkstat = jkstat;

	proctree = (ProcessorTree) hi.getAttribute("ptree");

	tp = new JingleTextPane("text/plain");

	display();
	validate();
    }

    public void stopLoop() {
	if (acp != null) {
	    acp.stopLoop();
	}
    }

    /*
     * Display an information panel appropriate to the Cpu item that is
     * selected.
     */
    private void display() {
	switch (hi.getType()) {
	    case SysItem.CPU:
		displayChip();
		break;
	    case SysItem.CPU_CORE:
		displayCore();
		break;
	    case SysItem.CPU_THREAD:
		displayThread();
		break;
	    case SysItem.CPU_CONTAINER:
		displaySummary();
		break;
	}
    }

    /*
     * Top level summary. This ought to be a variant on psrinfo.
     */
    private void displaySummary() {
	jvp.add(new JLabel("Processor Summary"));

	if (proctree.numChips() == 1) {
	    jvp.add(new JLabel("System contains 1 chip"));
	} else {
	    jvp.add(new JLabel("System contains " + proctree.numChips()
					+ " chips"));
	}

	StringBuilder sb = new StringBuilder();
	for (Long l : proctree.getChips()) {
	    sb.append(chipDetails(l));
	}
	tp.setText(sb.toString());
	jvp.add(new JScrollPane(tp));
    }

    /*
     * A processor chip.
     */
    private void displayChip() {
	jvp.add(new JLabel("Details of processor " + hi.getInstance()));
	tp.setText(chipDetails((Long) hi.getAttribute("chip")));
	jvp.add(new JScrollPane(tp));
	addAccessory();
    }

    /*
     * A processor core.
     */
    private void displayCore() {
	jvp.add(new JLabel("Details of processor core " + hi.getInstance()));
	addAccessory();
    }

    /*
     * A processor thread.
     */
    private void displayThread() {
	jvp.add(new JLabel("Details of processor thread " + hi.getInstance()));
	addAccessory();
    }

    /*
     * Add an accessory if we can.
     */
    private void addAccessory() {
	Kstat ks = (Kstat) hi.getAttribute("kstat");
	if (ks != null) {
	    acp = new AccessoryCpuPanel("cpu_stat", ks.getInst(),
                                "cpu_stat"+ks.getInstance(), 1, jkstat);
	    jvp.add(acp);
	}
    }

    private String chipDetails(Long l) {
	StringBuilder sb = new StringBuilder();
	String brand = "";
	String speed = "";

	sb.append("Physical processor ").append(l).append(" has ");
	if (proctree.numCores(l) == 1) {
	    sb.append("1 core\n");
	} else {
	    sb.append(proctree.numCores(l)).append(" cores\n");
	}
	if (proctree.isThreaded()) {
	    for (Long ll : proctree.getCores(l)) {
		sb.append("    Core ").append(ll).append(" has ");
		sb.append(proctree.numThreads(l, ll)).append(" threads\n");
	    }
	}
	// FIXME shouldn't need to loop
	for (Kstat ks : proctree.chipInfoStats(l)) {
	    brand = (String) ks.getData("brand");
	    speed = ks.getData("clock_MHz").toString();
	}
	sb.append("        ").append(brand).append("\n");
	sb.append("        Clock speed: ").append(speed).append(" MHz\n");
	return sb.toString();
    }
}
