/**
 * NetInfoPanel - shows Net status
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview.explorer;

import javax.swing.*;
import uk.co.petertribble.jkstat.api.*;
import uk.co.petertribble.jkstat.gui.AccessoryNetPanel;
import uk.co.petertribble.jkstat.gui.KstatTable;
import uk.co.petertribble.solview.InfoCommand;

public class NetInfoPanel extends InfoPanel {

    private AccessoryNetPanel acp;
    private JKstat jkstat;
    private Kstat ks;
    private KstatTable kt;

    /**
     * Display a Net information panel.
     */
    public NetInfoPanel(SysItem hi, JKstat jkstat) {
	super(hi);
	this.jkstat = jkstat;
	ks = (Kstat) hi.getAttribute("kstat");

	display();
	validate();
    }

    public void stopLoop() {
	if (acp != null) {
	    acp.stopLoop();
	}
	if (kt != null) {
	    kt.stopLoop();
	}
    }

    /*
     * Display an information panel appropriate to the Net item that is
     * selected.
     */
    private void display() {
	switch (hi.getType()) {
	    case SysItem.NET_INTERFACE:
		displayInterface();
		break;
	    case SysItem.NET_PROTO_IP:
		displayProtoIP();
		break;
	    case SysItem.NET_PROTO_TCP:
		displayProtoTCP();
		break;
	    case SysItem.NET_PROTO_UDP:
		displayProtoUDP();
		break;
	    case SysItem.NET_CONTAINER:
		displaySummary();
		break;
	}
    }

    /*
     * Top level summary.
     */
    private void displaySummary() {
	jvp.add(new JLabel("Network Summary"));
	jvp.add(new JLabel("Output from ifconfig -a"));

	// FIXME do netstat as well

	InfoCommand ic = new InfoCommand("IF", "/usr/sbin/ifconfig", "-a");
	jvp.add(new JScrollPane(new SysCmdPanel(ic)));
    }

    /*
     * A network interface
     */
    private void displayInterface() {
	if (ks != null) {
	    jvp.add(new JLabel("Details of Network Interface " + ks.getName()));
	    addAccessory();
	}
    }

    /*
     * Protocol for IP
     */
    private void displayProtoIP() {
	jvp.add(new JLabel("Network protocol: ip"));
	kt = new KstatTable("ip", "0", "ip", 5, jkstat);
	jvp.add(new JScrollPane(kt));
    }

    /*
     * Protocol for TCP
     */
    private void displayProtoTCP() {
	jvp.add(new JLabel("Network protocol: tcp"));
	kt = new KstatTable("tcp", "0", "tcp", 5, jkstat);
	jvp.add(new JScrollPane(kt));
    }

    /*
     * Protocol for UDP
     */
    private void displayProtoUDP() {
	jvp.add(new JLabel("Network protocol: udp"));
	kt = new KstatTable("udp", "0", "udp", 5, jkstat);
	jvp.add(new JScrollPane(kt));
    }

    /*
     * Add an accessory if we can.
     * NOTE: we've already checked for ks being non-null above
     */
    private void addAccessory() {
	acp = new AccessoryNetPanel(ks.getModule(),
				   ks.getInst(), ks.getName(), 5, jkstat);
	jvp.add(acp);
    }
}
