/**
 * ZFSconfig - represent the configuration of ZFS
 * @author Peter Tribble
 * @version 1.0
 *
 */

/*
 * I'm not sure how to handle metasets. presumably there's a parent class
 * of this one that holds the lists of metasets, or should that be here?
 */

package uk.co.petertribble.solview.explorer;

import java.util.Set;
import java.util.HashSet;
import uk.co.petertribble.solview.InfoCommand;

public class ZFSconfig {

    private boolean configured = true;
    private Set <String> zpools;
    // FIXME need one list per pool
    private Set <Zfilesys> zfilesys;

    public ZFSconfig() {
	zpools = new HashSet <String> ();
	zfilesys = new HashSet <Zfilesys> ();
	parse();
    }

    private void parse() {
	parse_zpool();
	parse_zfs();
    }

    /*
     * Parse zpool output. Populates the list of pools and gives some
     * information about each one.
     */
    private void parse_zpool() {
	InfoCommand ic = new InfoCommand("ZL", "/usr/sbin/zpool", "list -H");
	if (ic.exists()) {
	    String[] lines = ic.getOutput().split("\n");
	    for (int i = 0; i < lines.length; i++) {
		// create a zpool object for each filesystem
	    }
	} else {
	    configured = false;
	}
    }

    /*
     * Parsing zfs output: format is
     * NAME    USED  AVAIL  REFER  MOUNTPOINT
     * peter  91.5K  1.95G    40K  /peter
     */
    private void parse_zfs() {
	InfoCommand ic = new InfoCommand("ZF", "/usr/sbin/zfs", "list -H");
	if (ic.exists()) {
	    String[] lines = ic.getOutput().split("\n");
	    for (int i = 0; i < lines.length; i++) {
		String[] ds = lines[i].split("\\s+");
		if (ds.length != 5) {
		    System.out.println("Unable to parse zfs output");
		    System.out.println(lines[i]);
		} else {
		    // FIXME do we want to store this in a map by mountpoint?
		    Zfilesys zfs = new Zfilesys(ds[0]);
		    zfilesys.add(zfs);
		}
	    }
	} else {
	    configured = false;
	}
    }

    /**
     * Return the set of known filesystems.
     */
    public Set <Zfilesys> filesystems() {
	return zfilesys;
    }
}
